pub struct Parser {}Expand description
@acp:summary “Parser for source files”
Implementations
Sourceimpl Parser
impl Parser
pub fn new() -> Self
Sourcepub fn parse<P: AsRef<Path>>(&self, path: P) -> Result<ParseResult>
pub fn parse<P: AsRef<Path>>(&self, path: P) -> Result<ParseResult>
@acp:summary “Parse a source file and extract metadata”
Sourcepub fn parse_annotations(&self, content: &str) -> Vec<Annotation>
pub fn parse_annotations(&self, content: &str) -> Vec<Annotation>
@acp:summary “Parse @acp: annotations from source comments (RFC-001)” Extracts annotations with directive suffix support and multiline continuation.
Sourcepub fn parse_provenance(
&self,
lines: &[&str],
start_idx: usize,
) -> Option<ProvenanceMarker>
pub fn parse_provenance( &self, lines: &[&str], start_idx: usize, ) -> Option<ProvenanceMarker>
Parse provenance annotations from comment lines (RFC-0003)
Looks for @acp:source* annotations following the given start index. Returns a ProvenanceMarker if any provenance annotations are found.
Sourcepub fn parse_annotations_with_provenance(
&self,
content: &str,
) -> Vec<AnnotationWithProvenance>
pub fn parse_annotations_with_provenance( &self, content: &str, ) -> Vec<AnnotationWithProvenance>
Parse @acp: annotations with provenance support (RFC-0003)
Returns annotations paired with their provenance metadata if present. Provenance is detected from @acp:source* annotations following the main annotation.